# whisper-client

[![PyPI - Version](https://img.shields.io/pypi/v/whisper-client.svg)](https://pypi.org/project/whisper-client)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/whisper-client.svg)](https://pypi.org/project/whisper-client)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install whisper-client
```

## License

`whisper-client` is distributed under the terms of the [AGPLv3](https://www.gnu.org/licenses/agpl-3.0.en.html) license.
